@@ -15,11 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.9.2.1 2003/09/29 18:22:58 chpe Exp $
+ *  $Id: print-dialog.c,v 1.9.2.3 2003/11/05 13:33:52 chpe Exp $
  */
 
 #include "print-dialog.h"
+
 #include "ephy-prefs.h"
+
+#include <gtk/gtktogglebutton.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkstock.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -82,7 +85,9 @@ enum
 	TO_PROP,
 	FROM_PROP,
 	COLOR_PROP,
-	ORIENTATION_PROP
+	ORIENTATION_PROP,
+	PREVIEW_PROP,
+	SELECTION_PROP
 };
 
 enum
@@ -112,6 +117,8 @@ EphyDialogProperty properties [] =
 	{ FROM_PROP, "from_spinbutton", NULL, PT_NORMAL, NULL },
 	{ COLOR_PROP, "print_color_radiobutton", CONF_PRINT_COLOR, PT_NORMAL, NULL },
 	{ ORIENTATION_PROP, "orient_p_radiobutton", CONF_PRINT_ORIENTATION, PT_NORMAL, NULL },
+	{ PREVIEW_PROP, "preview_button", NULL, PT_NORMAL, NULL },
+	{ SELECTION_PROP, "selection_radiobutton", NULL, PT_NORMAL, NULL},
 
 	{ -1, NULL, NULL }
 };
@@ -154,15 +161,56 @@ print_dialog_get_type (void)
 
 }
 
+static void
+impl_show (EphyDialog *dialog)
+{
+	PrintDialog *print_dialog = PRINT_DIALOG (dialog);
+	EphyEmbed *embed = ephy_embed_dialog_get_embed (EPHY_EMBED_DIALOG (dialog));
+
+	EPHY_DIALOG_CLASS (parent_class)->show (dialog);
+
+	if (print_dialog->only_collect_info)
+	{
+		GtkWidget *button;
+
+		/* disappear preview button  */
+		button = ephy_dialog_get_control (EPHY_DIALOG (dialog),
+						  PREVIEW_PROP);
+		gtk_widget_hide (button);
+	}
+
+	if (ephy_embed_selection_can_copy (embed) != G_OK)
+	{
+		GtkWidget *widget;
+
+		/* Make selection button disabled */
+		widget = ephy_dialog_get_control (EPHY_DIALOG (dialog),
+						  SELECTION_PROP);
+
+		gtk_widget_set_sensitive (widget, FALSE);
+
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
+		{
+			GtkWidget *all_pages;
+ 			all_pages = ephy_dialog_get_control (EPHY_DIALOG (dialog),
+							     ALL_PAGES_PROP);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (all_pages), TRUE);
+		}
+	}
+}
+
 static void
 print_dialog_class_init (PrintDialogClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	EphyDialogClass *dialog_class = EPHY_DIALOG_CLASS (klass);
 
         parent_class = g_type_class_peek_parent (klass);
 
         object_class->finalize = print_dialog_finalize;
 
+	dialog_class->show = impl_show;
+
 	print_dialog_signals[PREVIEW] =
                 g_signal_new ("preview",
                               G_OBJECT_CLASS_TYPE (object_class),
@@ -228,8 +276,11 @@ print_dialog_new (EphyEmbed *embed,
 				     "embed", embed,
 				     NULL));
 
-	if (!embed) dialog->only_collect_info = TRUE;
-	dialog->ret_info = ret_info;
+	if (ret_info != NULL)
+	{
+		dialog->only_collect_info = TRUE;
+		dialog->ret_info = ret_info;
+	}
 
 	return EPHY_DIALOG(dialog);
 }
@@ -246,8 +297,11 @@ print_dialog_new_with_parent (GtkWidget *window,
 				     "ParentWindow", window,
 				     NULL));
 
-	if (!embed) dialog->only_collect_info = TRUE;
-	dialog->ret_info = ret_info;
+	if (ret_info != NULL)
+	{
+		dialog->only_collect_info = TRUE;
+		dialog->ret_info = ret_info;
+	}
 
 	return EPHY_DIALOG(dialog);
 }
@@ -391,18 +445,19 @@ print_dialog_print (EphyDialog *dialog)
 	if(PRINT_DIALOG(dialog)->only_collect_info && PRINT_DIALOG(dialog)->ret_info)
 	{
 		*(PRINT_DIALOG(dialog)->ret_info) = info;
-	}
-	else
-	{
-		embed = ephy_embed_dialog_get_embed
-			(EPHY_EMBED_DIALOG(dialog));
-		g_return_if_fail (embed != NULL);
 
-		info->preview = FALSE;
-		ephy_embed_print (embed, info);
-		print_free_info (info);
+		/* When in collect_info mode the caller owns the reference */
+		return;
 	}
 
+	embed = ephy_embed_dialog_get_embed
+		(EPHY_EMBED_DIALOG(dialog));
+	g_return_if_fail (embed != NULL);
+
+	info->preview = FALSE;
+	ephy_embed_print (embed, info);
+	print_free_info (info);
+
 	g_object_unref (G_OBJECT(dialog));
 }
 
@@ -416,18 +471,17 @@ print_dialog_preview (EphyDialog *dialog)
 
 	if(PRINT_DIALOG(dialog)->only_collect_info && PRINT_DIALOG(dialog)->ret_info)
 	{
-		*(PRINT_DIALOG(dialog)->ret_info) = info;
+		return;
 	}
-	else
-	{
-		embed = ephy_embed_dialog_get_embed
-			(EPHY_EMBED_DIALOG(dialog));
-		g_return_if_fail (embed != NULL);
 
-		info->preview = TRUE;
-		ephy_embed_print (embed, info);
-		print_free_info (info);
-	}
+	embed = ephy_embed_dialog_get_embed
+			(EPHY_EMBED_DIALOG(dialog));
+	g_return_if_fail (embed != NULL);
+
+	info->preview = TRUE;
+	ephy_embed_print (embed, info);
+	print_free_info (info);
+
 	g_signal_emit (G_OBJECT (dialog), print_dialog_signals[PREVIEW], 0);
 
 	g_object_unref (G_OBJECT(dialog));
@@ -437,6 +491,12 @@ void
 print_cancel_button_cb (GtkWidget *widget,
 			EphyDialog *dialog)
 {
+	if (PRINT_DIALOG (dialog)->only_collect_info)
+	{
+		/* When in collect_info mode the caller owns the reference */
+		return;
+	}
+
 	g_object_unref (G_OBJECT(dialog));
 }
 
@@ -451,9 +511,5 @@ void
 print_preview_button_cb (GtkWidget *widget,
 		         EphyDialog *dialog)
 {
-	//FIXME: Don't show preview button at all.
-	if(!(PRINT_DIALOG(dialog)->only_collect_info))
-		print_dialog_preview (dialog);
+	print_dialog_preview (dialog);
 }
-
-
