@@ -154,6 +154,7 @@ language_editor_update_pref (LanguageEditor *editor)
 		gtk_tree_model_get_value (GTK_TREE_MODEL (editor->priv->model),
 					  &iter, COL_DATA, &val);
 		index = g_value_get_int (&val);
+		g_value_unset (&val);
 
 		strings = g_slist_append(strings, GINT_TO_POINTER(index));
 	}
@@ -212,16 +213,17 @@ language_editor_remove_button_clicked_cb (GtkButton *button,
 
 	for (r = rlist; r != NULL; r = r->next)
 	{
-		GtkTreePath *node;
+		GtkTreePath *path;
 
-		node = gtk_tree_row_reference_get_path
+		path = gtk_tree_row_reference_get_path
 			((GtkTreeRowReference *)r->data);
 
-		gtk_tree_model_get_iter (model, &iter, node);
+		gtk_tree_model_get_iter (model, &iter, path);
 
 		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 
 		gtk_tree_row_reference_free ((GtkTreeRowReference *)r->data);
+		gtk_tree_path_free (path);
 	}
 
 	g_list_foreach (llist, (GFunc)gtk_tree_path_free, NULL);
